@@ -107,12 +107,19 @@ class Index(Generic[K, T]):
     def __getitem__(self, key: Union[slice, K]) -> T:
         if not isinstance(key, slice):
             return self.eq(key)
-        start_index = None
-        stop_index = None
-        if key.start is not None:
-            start_index = self.gteq_index(key.start)
-        if key.stop is not None:
-            stop_index = self.lt_index(key.stop)
+
+        start_index = key.start
+        if start_index is not None:
+            start_index = self.gteq_index(start_index)
+            if start_index is None:
+                return []
+
+        stop_index = key.stop
+        if stop_index is not None:
+            stop_index = self.gteq_index(stop_index)
+            if stop_index is None:
+                return []
+
         return self.items[start_index:stop_index:key.step]
 
     def eq(self, key: K) -> T:
@@ -176,31 +183,3 @@ class Index(Generic[K, T]):
         if index == len(self.keys):
             return None
         return index
-
-
-def print_result(func, n):
-    print(format(func, "<15") + "│", end="")
-    if n is None:
-        print(format("", "<14") + " -")
-        return
-    s = (n + 1) * 2
-    spaces = (" " * s) + "^"
-    print(format(spaces, "<14") + format(n, ">2"))
-
-
-def test():
-    class Item:
-        def __init__(self, val):
-            self.val = val
-    item_vals = [-4, 0, 2, 4, 5, 7]
-    items = [Item(v) for v in item_vals]
-    keyindex = Index(items, "val")
-    vals = 5, 5.5, -7, 9
-    funcs = keyindex.lteq_index, keyindex.lt_index, keyindex.gt_index, keyindex.gteq_index
-    for f in funcs:
-        print()
-        print(format("ind │ ", ">17") + "".join(f"{i:>{2}}" for i, _ in enumerate(item_vals)))
-        print(format("val │ ", ">17") + "".join(f"{i:>{2}}" for i in item_vals))
-        print("─" * 15 + "┼" + "─" * 18)
-        for v in vals:
-            print_result(f"{f.__name__}({v})", f(v))
